==> kubernetes-model-node-5.3.2-sources.jar: io/fabric8/kubernetes/api/model/node/v1alpha1/RuntimeClassListBuilder.java <==
package io.fabric8.kubernetes.api.model.node.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class RuntimeClassListBuilder extends io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassListFluentImpl<io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassList,io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassListBuilder> {

    io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassListFluent<?> fluent;
    Boolean validationEnabled;

    public RuntimeClassListBuilder() {
        this(true);
    }

    public RuntimeClassListBuilder(Boolean validationEnabled) {
        this(new RuntimeClassList(), validationEnabled);
    }

    public RuntimeClassListBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassListFluent<?> fluent) {
        this(fluent, true);
    }

    public RuntimeClassListBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassListFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new RuntimeClassList(), validationEnabled);
    }

    public RuntimeClassListBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassListFluent<?> fluent,io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassList instance) {
        this(fluent, instance, true);
    }

    public RuntimeClassListBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassListFluent<?> fluent,io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassList instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public RuntimeClassListBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassList instance) {
        this(instance,true);
    }

    public RuntimeClassListBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassList instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassList build() {
        RuntimeClassList buildable = new RuntimeClassList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        RuntimeClassListBuilder that = (RuntimeClassListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-node-5.6.0-sources.jar: io/fabric8/kubernetes/api/model/node/v1alpha1/RuntimeClassListBuilder.java <==
package io.fabric8.kubernetes.api.model.node.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class RuntimeClassListBuilder extends io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassListFluentImpl<io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassList,io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassListBuilder> {

    io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassListFluent<?> fluent;
    java.lang.Boolean validationEnabled;

    public RuntimeClassListBuilder() {
        this(true);
    }

    public RuntimeClassListBuilder(java.lang.Boolean validationEnabled) {
        this(new RuntimeClassList(), validationEnabled);
    }

    public RuntimeClassListBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassListFluent<?> fluent) {
        this(fluent, true);
    }

    public RuntimeClassListBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassListFluent<?> fluent,java.lang.Boolean validationEnabled) {
        this(fluent, new RuntimeClassList(), validationEnabled);
    }

    public RuntimeClassListBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassListFluent<?> fluent,io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassList instance) {
        this(fluent, instance, true);
    }

    public RuntimeClassListBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassListFluent<?> fluent,io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassList instance,java.lang.Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public RuntimeClassListBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassList instance) {
        this(instance,true);
    }

    public RuntimeClassListBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassList instance,java.lang.Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassList build() {
        RuntimeClassList buildable = new RuntimeClassList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        RuntimeClassListBuilder that = (RuntimeClassListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
